# scraper2_hj3415/app/nfs/domain/endpoint.py
from __future__ import annotations

from enum import StrEnum


class EndpointKind(StrEnum):
    C101 = "c101"
    C103 = "c103"
    C104 = "c104"
    C106 = "c106"
    C108 = "c108"
