from __future__ import annotations


class DartClientError(Exception):
    """OpenDART 클라이언트 공통 예외."""


class DartApiResponseError(DartClientError):
    """OpenDART 응답 status가 정상('000', '013')이 아닐 때."""


class DartConnectionError(DartClientError):
    """네트워크 / 타임아웃 / 일시 오류."""
