# scraper2_hj3415/app/nfs/adapters/out/playwright/browser.py
from __future__ import annotations

from playwright.async_api import Page

from .capabilities import (
    PlaywrightInteraction,
    PlaywrightNavigation,
    PlaywrightScope,
    PlaywrightTable,
    PlaywrightText,
    PlaywrightWait,
    _PlaywrightBase,  # pyright: ignore[reportPrivateUsage]
)


class PlaywrightBrowser(
    PlaywrightNavigation,
    PlaywrightWait,
    PlaywrightInteraction,
    PlaywrightText,
    PlaywrightScope,
    PlaywrightTable,
):
    def __init__(self, page: Page):
        _PlaywrightBase.__init__(self, page)
